@@ -1,6 +1,6 @@
 #!/bin/sh
 if [ -e /android/system/boot/android-ramdisk.img ]; then
-    mount -t tmpfs tmpfs $LXC_ROOTFS_PATH
+    mount -n -t tmpfs tmpfs $LXC_ROOTFS_PATH
     INITRD=/android/system/boot/android-ramdisk.img
 elif [ -e /boot/android-ramdisk.img ]; then
     rm -Rf $LXC_ROOTFS_PATH
@@ -16,11 +16,17 @@ cat $INITRD | gzip -d | cpio -i
 # Create /dev/pts if missing
 mkdir -p $LXC_ROOTFS_PATH/dev/pts
 
+# Pass /sockets through
+rm -Rf /dev/socket
+mkdir -p /dev/socket $LXC_ROOTFS_PATH/socket
+mount -n -o bind,rw /dev/socket $LXC_ROOTFS_PATH/socket
+
 # Disable adbd
 rm $LXC_ROOTFS_PATH/sbin/adbd
 
 # Make sure the ubuntu_chroot init service does not get started
 sed -i '/ubuntu_chroot init$/,+2d' $LXC_ROOTFS_PATH/init.rc
+sed -i '/on early-init/a \    mkdir /dev/socket\n\    mount none /socket /dev/socket bind' $LXC_ROOTFS_PATH/init.rc
 
 cp -a /var/lib/lxc/android/overrides/* $LXC_ROOTFS_PATH
 
@@ -33,6 +39,6 @@ if [ "$INITRD" = "/android/system/boot/android-ramdisk.img" ]; then
 
     for dir in /android/*; do
         mkdir -p $LXC_ROOTFS_PATH/$(basename $dir)
-        mount -o bind,recurse $dir $LXC_ROOTFS_PATH/$(basename $dir)
+        mount -n -o bind,recurse $dir $LXC_ROOTFS_PATH/$(basename $dir)
     done
 fi
